MyModelFirestoreRepository class
- Inheritance
-
- Object
- FirestoreRepositoryImpl<
MyModel> - MyModelFirestoreRepository
Constructors
Properties
- collectionPath → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serializer
→ FirestoreSerializer<
MyModel> -
no setteroverride
Methods
-
createDocument(
MyModel data) → Future -
throws Exception if there was an error.
inherited
-
deleteDocument(
String id) → Future -
throws Exception if there was an error.
inherited
-
getCollectionRef(
) → CollectionReference< MyModel> -
inherited
-
listenToAll(
{bool includeMetadataChanges = false}) → Stream< Resource< List< >MyModel> > -
streams
Failureif there was an error. streams NoDataFailure if no documents existinherited -
listenToDocument(
String id, {bool includeMetadataChanges = false}) → Stream< Resource< MyModel> > -
streams
Failureif there was an error. streams NoDataFailure if document does not existinherited -
listenToDocumentWithMetadata(
String id, {bool includeMetadataChanges = false}) → Stream< Resource< TSnapshot< >MyModel> > -
streams
Failureif there was an error. streams NoDataFailure if document does not existinherited -
listenToQuery(
QueryApplier< MyModel> applyQuery, {bool includeMetadataChanges = false}) → Stream<Resource< List< >MyModel> > -
streams
Failureif there was an error. streams NoDataFailure if no documents existinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
QueryApplier< MyModel> applyQuery) → Future<Resource< List< >MyModel> > -
inherited
-
readAll(
) → Future< Resource< List< >MyModel> > -
returns
Failureif there was an error. returns NoDataFailure if documents do not existinherited -
readDocument(
String id) → Future< Resource< MyModel> > -
returns
Failureif there was an error. returns NoDataFailure if document does not existinherited -
readDocumentWithMetadata(
String id) → Future< Resource< TSnapshot< >MyModel> > -
returns
Failureif there was an error. returns NoDataFailure if document does not existinherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateDocument(
MyModel data, {bool createIfDoesNotExist = false}) → Future -
throws Exception if there was an error.
inherited
-
updateDocumentFields(
String id, Map< String, dynamic> fields) → Future -
throws Exception if there was an error.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited